@@ -25,6 +25,7 @@ Copyright (C) 2017-2023  Salvo "LtWorf" Tomaselli
 #include "btreeiterator.h"
 #include "bookmarkaction.h"
 #include "passaction.h"
+#include "otpaction.h"
 #include "searchaction.h"
 #include "ynewaction.h"
 
@@ -35,6 +36,7 @@ Tree::Tree(QObject *parent) : QObject(parent) {
     this->searchprovider = settings.value("Source/SearchProvider", true).toBool();
     this->ynew = settings.value("Source/YnewProvider", true).toBool();
     this->pass = settings.value("Source/pass", true).toBool();
+    this->otp = settings.value("Source/pass", true).toBool();
 
     if(this->desktop)
         this->watcher.addPaths(*DesktopAction::GetPaths());
@@ -46,6 +48,8 @@ Tree::Tree(QObject *parent) : QObject(parent) {
         this->watcher.addPaths(*YnewAction::GetPaths());
     if(this->pass)
         this->watcher.addPaths(*PassAction::GetPaths());
+    if(this->otp)
+        this->watcher.addPaths(*OtpAction::GetPaths());
 
     connect(
         &this->watcher,
@@ -87,6 +91,8 @@ void Tree::rescan() {
             YnewAction::LoadYnewActions(&sorted_tree, this->action_parent);
         if (this->pass)
             PassAction::LoadPassActions(&sorted_tree, this->action_parent);
+        if(this->otp)
+            OtpAction::LoadOtpActions(&sorted_tree, this->action_parent);
         BTreeIterator i(&sorted_tree);
 
         while (i.hasNext()) {
